
# PyFactorial

This is a simple Python package for calculating factorials.

## Installation

You can install PyFactorial using `pip`:

```bash
pip install pyfactorial
```

## Usage

To use the `factorial` function in your Python code, first import it:

```python
from pyfactorial.module import factorial
```

Then, you can calculate the factorial of a non-negative integer:


```python
result = factorial(5)
print(f"The factorial of 5 is {result}")
```
